@@ -3,11 +3,11 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp;
 use Exporter;
-use File::Find;
+use File::Find::Rule;
 use File::Temp qw(tempfile);
 
 our @ISA = qw(Exporter);
@@ -18,6 +18,8 @@ sub new {
 }
 sub read {
 
+    # for the non-OO interface
+
     if (ref($_[0]) ne 'File::Edit::Portable'){
         if (wantarray){
             my @ret = pread(@_);
@@ -65,6 +67,8 @@ sub read {
 }
 sub write {
 
+    # for the non-OO interface
+
     if (ref($_[0]) ne 'File::Edit::Portable'){
         pwrite(@_);
         return 1;
@@ -116,54 +120,35 @@ sub dir {
     my $self = shift;
     $self->_config(@_);
 
-    my $dir = $self->{dir};
-    my $types = $self->{types};
     my $recsep = $self->{custom_recsep};
-    my $list = $self->{list};
 
-    my @files;
+    my @types;
 
-    find({wanted => sub {
-            
-                return if ! -f;
+    if ($self->{types}){
+        @types = @{ $self->{types} };
+    }
+    else {
+        @types = qw(*);
+    }
 
-                if ($types){
-                    my $exts = join('|', @$types);
+    my $find = File::Find::Rule->new;
+    
+    $find->maxdepth($self->{maxdepth}) if $self->{maxdepth};
+    $find->file;
+    $find->name(@types);
 
-                    if ($_ !~ /\.(?:$exts)$/i){
-                        return;
-                    }
-                } 
+    my @files = $find->in($self->{dir});
 
-                my $file = $File::Find::name;
-
-                push @files, $file;
-            }, 
-            no_chdir => 1,
-        }, 
-        $dir,
-    );
-
-    return @files if $list;
+    return @files if $self->{list};
 
     for my $file (@files){
         my @contents = $self->read(file => $file);
 
-        if ($recsep){
-
-            $self->write(
-                        file => $file, 
-                        contents => \@contents, 
-                        recsep =>$recsep
-                    );
-        }
-        else {
-            $self->write(
+        $self->write(
                     file => $file, 
                     contents => \@contents, 
-                    recsep => $self->platform_recsep
+                    recsep => $recsep || $self->platform_recsep,
                 );
-        }
     }
 
     return @files;
@@ -179,14 +164,32 @@ sub recsep {
 
     croak "recsep() couldn't acquire file handle" if ! $fh;
 
+    my @contents = <$fh>;
+
+    my $recsep;
+
+    if (! $contents[0]){
+
+        # we've got an empty file...
+        # we'll set recsep to the local platform's
+
+        $recsep = $self->platform_recsep;
+        $self->{recsep} = $recsep;
+        $recsep = unpack "H*", $recsep;
+        $recsep =~ s/0/\\0/g;
+
+        return $recsep;
+    }
+
+    seek $fh, 0, 0;
+
     if (<$fh> =~ /(\R)/){
         $self->{recsep} = $1;
-        $ENV{FEP_RECSEP} = $1;
     }
 
     close $fh or croak "recsep() can't close file $file!: $!";
     
-    my $recsep = unpack "H*", $self->{recsep};
+    $recsep = unpack "H*", $self->{recsep};
 
     $recsep =~ s/0/\\0/g;
 
@@ -230,8 +233,6 @@ sub pread {
 
     my $rw = File::Edit::Portable->new;
 
-    $ENV{FEP_IS_READ} = 1;
-
     if (! $file){ 
         croak "pread() requires a file name sent in!";
     }
@@ -299,10 +300,12 @@ sub _config {
 
     $self->{custom_recsep} = $p{recsep};
     delete $p{recsep};
-    delete $self->{testing} if ! $p{testing};
+
+    delete $self->{testing};
     delete $self->{copy};
     delete $self->{types};
     delete $self->{list};
+    delete $self->{maxdepth};
 
     for (keys %p){
         $self->{$_} = $p{$_};
@@ -430,7 +433,7 @@ Get the local platforms record separator. This will be in string representation.
 
 Rewrite line endings to the current platform's in all files in a directory recursively.
 
-    $rw->dir(dir => '/path/to/files/');
+    $rw->dir(dir => '/path/to/files');
     
 There's also a minimal non-OO interface...
 
@@ -506,14 +509,16 @@ Parameters:
 
 C<dir =E<gt> '/path/to/files'>: Mandatory.
 
-C<types =E<gt> ['txt', 'dat']>: Optional. Specify file extensions (less the dot) within an array reference and we'll only work on these file types.
+C<types =E<gt> ['*.txt', '*.dat']>: Optional. Specify wildcard combinations for files to work on. We'll accept anything that L<File::Find::Rule's|http://search.cpan.org/~rclamp/File-Find-Rule-0.33/lib/File/Find/Rule.pm> C<name()> method does.
+
+C<maxdepth =E<gt> 1>: Optional: Specify how many levels of recursion to do after entering the directory. We'll do a full recurse through all sub-directories if this parameter is not set.
 
 C<recsep =E<gt> "\r\n">: Optional: If this parameter is not sent in, we'll replace the line endings with that of the current platform we're operating on. Otherwise, we'll use the double-quoted value sent in.
 
 
 =head2 C<recsep('file')>
 
-Returns a string of the hex representation of the line endings (record separators) in 'file'. For example, "\0d\0a" will be returned for Windows line endings (CRLF).
+Returns a string of the hex representation of the line endings (record separators) in 'file'. For example, "\0d\0a" will be returned for Windows line endings (CRLF). If an empty file is being checked, we'll return the local platform's record separator.
 
 =head2 C<platform_recsep>
 
